News for hackers. Stuff that matters.
Re:How copying an int made my code 11 times faster by yazaddaruvala on Monday February 20, 2017 @02:33AM (#13685210)
As I understand it, this is partially the plan. Historically it has just been waiting for a compiler refactor to MIR (which is now complete). I'm not sure why more optimization RFCs haven't been created and prioritized.

There are no comments on this comment yet.